==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/registry/content/danmaku/DanmakuTemplates.java <==
package cc.thonly.reverie_dreams.registry.content.danmaku;

import cc.thonly.reverie_dreams.component.DanmakuProperties;
import cc.thonly.reverie_dreams.data.danmaku.DanmakuTrajectory;
import cc.thonly.reverie_dreams.registry.RegistryHandlers;
import cc.thonly.reverie_dreams.registry.content.component.RDDataComponentTypes;
import cc.thonly.reverie_dreams.registry.content.item.RDItems;
import it.unimi.dsi.fastutil.objects.Object2ObjectLinkedOpenHashMap;
import java.util.LinkedHashMap;
import java.util.Map;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_6880;
import net.minecraft.class_7923;
import net.minecraft.class_9326;

public class DanmakuTemplates {
    private static final Map<class_2960, DanmakuTrajectory> TEMPLATES = new Object2ObjectLinkedOpenHashMap<>();
    private static final Map<class_2960, class_1799> TEMPLATE_ITEM_STACKS = new Object2ObjectLinkedOpenHashMap<>();
    static {
        var simple = registerTemplateItem(DanmakuTrajectories.SINGLE);
        var triple = registerTemplateItem(DanmakuTrajectories.TRIPLE);
        var bullet = registerTemplateItem(DanmakuTrajectories.BULLET);
        var star = registerTemplateItem(DanmakuTrajectories.STAR);
        var heart = registerTemplateItem(DanmakuTrajectories.HEART);
        var x = registerTemplateItem(DanmakuTrajectories.X);
        var round = registerTemplateItem(DanmakuTrajectories.ROUND);
        var ring = registerTemplateItem(DanmakuTrajectories.RING);
    }

    public static void init() {

    }

    public static DanmakuTrajectory registerTemplateItem(DanmakuTrajectory entry) {
        class_2960 id = RegistryHandlers.DANMAKU_TRAJECTORY.method_10221(entry);
        assert id != null;
        return registerTemplateItem(id, entry);
    }

    public static DanmakuTrajectory registerTemplateItem(class_2960 key, DanmakuTrajectory entry) {
        assert key != null;
        TEMPLATES.put(key, entry);
        TEMPLATE_ITEM_STACKS.put(key, createItemStack(key));
        return entry;
    }

    public static class_1799 createItemStack(class_2960 key) {
        class_6880<class_1792> entry = class_7923.field_41178.method_47983(RDItems.SPELL_CARD_TEMPLATE);
        return new class_1799(entry, 1, class_9326.method_57841().method_57854(RDDataComponentTypes.DANMAKU_PROPERTIES, DanmakuProperties.ofDefault().withTemplateId(key)).build());
    }

    public static Map<class_2960, DanmakuTrajectory> getRegistryView() {
        return new LinkedHashMap<>(TEMPLATES);
    }

    public static Map<class_2960, class_1799> getRegistryItemStackView() {
        return new LinkedHashMap<>(TEMPLATE_ITEM_STACKS);
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/registry/content/danmaku/DanmakuTemplates.java <==
package cc.thonly.reverie_dreams.registry.content.danmaku;

import cc.thonly.reverie_dreams.component.DanmakuProperties;
import cc.thonly.reverie_dreams.data.danmaku.DanmakuTrajectory;
import cc.thonly.reverie_dreams.registry.RegistryHandlers;
import cc.thonly.reverie_dreams.registry.content.component.RDDataComponents;
import cc.thonly.reverie_dreams.registry.content.item.RDItems;
import it.unimi.dsi.fastutil.objects.Object2ObjectLinkedOpenHashMap;
import java.util.LinkedHashMap;
import java.util.Map;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_6880;
import net.minecraft.class_7923;
import net.minecraft.class_9326;

public class DanmakuTemplates {
    private static final Map<class_2960, DanmakuTrajectory> TEMPLATES = new Object2ObjectLinkedOpenHashMap<>();
    private static final Map<class_2960, class_1799> TEMPLATE_ITEM_STACKS = new Object2ObjectLinkedOpenHashMap<>();
    static {
        var simple = registerTemplateItem(DanmakuTrajectories.SINGLE);
        var triple = registerTemplateItem(DanmakuTrajectories.TRIPLE);
        var bullet = registerTemplateItem(DanmakuTrajectories.BULLET);
        var star = registerTemplateItem(DanmakuTrajectories.STAR);
        var heart = registerTemplateItem(DanmakuTrajectories.HEART);
        var x = registerTemplateItem(DanmakuTrajectories.X);
        var round = registerTemplateItem(DanmakuTrajectories.ROUND);
        var ring = registerTemplateItem(DanmakuTrajectories.RING);
    }

    public static void init() {

    }

    public static DanmakuTrajectory registerTemplateItem(DanmakuTrajectory entry) {
        class_2960 id = RegistryHandlers.DANMAKU_TRAJECTORY.method_10221(entry);
        assert id != null;
        return registerTemplateItem(id, entry);
    }

    public static DanmakuTrajectory registerTemplateItem(class_2960 key, DanmakuTrajectory entry) {
        assert key != null;
        TEMPLATES.put(key, entry);
        TEMPLATE_ITEM_STACKS.put(key, createItemStack(key));
        return entry;
    }

    public static class_1799 createItemStack(class_2960 key) {
        class_6880<class_1792> entry = class_7923.field_41178.method_47983(RDItems.SPELL_CARD_TEMPLATE);
        return new class_1799(entry, 1, class_9326.method_57841().method_57854(RDDataComponents.DANMAKU_PROPERTIES, DanmakuProperties.ofDefault().withTemplateId(key)).build());
    }

    public static Map<class_2960, DanmakuTrajectory> getRegistryView() {
        return new LinkedHashMap<>(TEMPLATES);
    }

    public static Map<class_2960, class_1799> getRegistryItemStackView() {
        return new LinkedHashMap<>(TEMPLATE_ITEM_STACKS);
    }
}
